SystemOrganization addCategory: #'Zinc-Tests'!

TestCase subclass: #ZnBivalentWriteStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:43'!
testByteWriting
	| string |
	string := String streamContents: [ :stream | | writeStream |
		writeStream := ZnBivalentWriteStream on: stream.
		writeStream nextPut: 97; nextPutAll: #(98 99) asByteArray ].
	self assert: string asByteArray = #(97 98 99) asByteArray! !

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:43'!
testByteWritingToTranscript
	| writeStream |
	writeStream := ZnBivalentWriteStream on: Transcript.
	writeStream nextPut: 97; nextPutAll: #(98 99) asByteArray
! !

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 21:02'!
testCharacterWriting
	| bytes |
	bytes := ByteArray streamContents: [ :stream | | writeStream |
		writeStream := ZnBivalentWriteStream on: stream.
		writeStream nextPut: $a; space; nextPutAll: '123' ].
	self assert: bytes = 'a 123' asByteArray! !

TestCase subclass: #ZnBufferedWriteStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnBufferedWriteStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/8/2010 09:54'!
testWriting
	| string |
	string := String streamContents: [ :stringStream | | bufferedStream |
		bufferedStream := ZnBufferedWriteStream on: stringStream.
		0 to: 9 do: [ :each | bufferedStream nextPut: (Character digitValue: each) ].
		bufferedStream flush ].
	self assert: string = '0123456789'! !

!ZnBufferedWriteStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/8/2010 09:53'!
testWritingOverflow
	| string |
	string := String streamContents: [ :stringStream | | bufferedStream |
		bufferedStream := ZnBufferedWriteStream on: stringStream.
		bufferedStream sizeBuffer: 8.
		0 to: 9 do: [ :each | bufferedStream nextPut: (Character digitValue: each) ].
		bufferedStream nextPutAll: '0123'; nextPutAll: '4567'; nextPutAll: '89'.
		bufferedStream nextPutAll: '0123456789'; nextPutAll: '0123456789'.
		bufferedStream flush ].
	self assert: string = '0123456789012345678901234567890123456789'! !

TestCase subclass: #ZnCharacterEncoderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnCharacterEncoderTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 11/30/2010 11:57'!
decodeBytes: bytes with: encoder
	| input |
	input := bytes readStream.
	^ String streamContents: [ :stream |
		[ input atEnd ] whileFalse: [ 
			stream nextPut: (encoder nextFromStream: input) ] ]! !

!ZnCharacterEncoderTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 11/30/2010 11:57'!
encodeString: string with: encoder
	^ ByteArray streamContents: [ :stream |
		string do: [ :each |
			encoder nextPut: each toStream: stream ] ]! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:44'!
testLatin2Encoder
	"Example characters taken from http://en.wikipedia.org/wiki/Latin2"
	
	| encoder inputBytes outputBytes inputString outputString |
	encoder := ZnCharacterEncoder newForEncoding: 'latin2'.
	inputString := String 
		with: (16r0154 asCharacter) with: (16r0110 asCharacter) 
		with: ( 16r0155 asCharacter) with: (16r0111 asCharacter).
	inputBytes := #(192 208 224 240) asByteArray.
	outputBytes := self encodeString: inputString with: encoder.
	self assert: outputBytes = inputBytes.
	outputString := self decodeBytes: inputBytes with: encoder.
	self assert: outputString = inputString ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:45'!
testNullEncoder
	| encoder bytes string |
	encoder := ZnNullEncoder new.
	bytes := self encodeString: 'abc' with: encoder.
	self assert: bytes = #(97 98 99) asByteArray.
	string := self decodeBytes: #(65 66 67) asByteArray with: encoder.
	self assert: string = 'ABC' ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:44'!
testUTF8Encoder
	"The examples are taken from http://en.wikipedia.org/wiki/UTF-8#Description"
	
	| encoder inputBytes outputBytes inputString outputString |
	encoder := ZnUTF8Encoder new.
	inputString := String with: $$ with: (16r00A2 asCharacter) with: (16r20AC asCharacter) with: (16r024B62 asCharacter).
	inputBytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	outputBytes := self encodeString: inputString with: encoder.
	self assert: outputBytes = inputBytes.
	outputString := self decodeBytes: inputBytes with: encoder.
	self assert: outputString = inputString ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/30/2010 13:42'!
testUTF8EncoderAuto
	| encoder inputString bytes outputString |
	encoder := ZnUTF8Encoder new.
	inputString := String withAll: ((1 to: 3072) collect: [ :each | Character value: each ]).
	bytes := self encodeString: inputString with: encoder. 
	outputString := self decodeBytes: bytes with: encoder.
	self assert: inputString = outputString ! !

!ZnCharacterEncoderTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:44'!
testUTF8EncoderByteCount	
	| encoder |
	encoder := ZnUTF8Encoder new.
	self assert: (encoder encodedByteCountFor: $$) = 1.
	self assert: (encoder encodedByteCountFor: (16r00A2 asCharacter)) = 2.
	self assert: (encoder encodedByteCountFor: (16r20AC asCharacter)) = 3.
	self assert: (encoder encodedByteCountFor: (16r024B62 asCharacter)) = 4! !

TestCase subclass: #ZnChunkedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:07'!
testReading
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	self assert: plain = data! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:18'!
testReadingGzip
	| data gzipped chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	plain := (GZipReadStream on: (ZnChunkedReadStream on: chunked readStream)) upToEnd.
	self assert: data = plain ! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:17'!
testReadingGzipStepped
	| data gzipped chunked unchunked ungzipped |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	unchunked := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	ungzipped := (GZipReadStream on: unchunked) upToEnd.
	self assert: gzipped = unchunked.
	self assert: data = ungzipped ! !

TestCase subclass: #ZnClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:25'!
testDelete
	| server response |
	server := ZnServer on: 1701.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient delete: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'DELETE').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:07'!
testGetJpeg
	| url result |
	url := 'http://caretaker.wolf359.be/sun-fire-x2100.jpg'.
	result := ZnClient getJpeg: url.
	self assert: result isForm! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:07'!
testGetSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	response := ZnClient get: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small')! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:07'!
testHeadSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	response := ZnClient head: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: response hasEntity not! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:26'!
testPost
	| server response data |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient post: 'http://localhost:1701/echo' data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'POST').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:26'!
testPostUnicodeUtf8
	| server response data |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 0 to: 16r024F do: [ :each | stream nextPut: each asCharacter ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient post: 'http://localhost:1701/echo' data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'POST').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:26'!
testPut
	| server response data |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient put: 'http://localhost:1701/echo' data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'PUT').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnCredentialTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:26'!
testBasicAuthorization
	| server response client cred |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		"client logProgressToTranscript."
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'secret';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 200).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:27'!
testBasicAuthorizationFailure
	| server response client cred |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		"client logProgressToTranscript."
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'wrong';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 401).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:27'!
testDigestAuthorization
	| server response client cred |
	self assert: ZnDigestAuthenticator hasMD5Support description: 'MD5 hashing support is required for Digest authentication.'.
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		"client logProgressToTranscript."
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Digest').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'secret';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 200).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:27'!
testDigestAuthorizationFailure
	| server response client cred |
	self assert: ZnDigestAuthenticator hasMD5Support description: 'MD5 hashing support is required for Digest authentication.'.
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		"client logProgressToTranscript."
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Digest').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'wrong';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 401).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:27'!
testFindHandlerFor
	| server response client handler |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		"client logProgressToTranscript."
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		handler := ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate').
		self assert: (handler = ZnBasicCredential).
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:28'!
testFindRealmFor
	| server response client realm |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		"client logProgressToTranscript."
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		realm := ZnCredential findRealmFor: (response headers at: 'WWW-Authenticate').
		self assert: (realm includesSubString: 'Zinc').
	]
		ensure: [ server stop ]! !

!ZnCredentialTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:28'!
testZnServerBasicAuthRealm
	| server response client cred |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		self assert: server serverSocket localPort = 1701.
		client := ZnUserAgent new.
		"client logProgressToTranscript."
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		cred := (ZnCredential findHandlerFor: (response headers at: 'WWW-Authenticate')) new
					username: 'foo';
					password: 'secret';
					domain: client request url authority;
					yourself.
		cred linkToAuthRequest: (response headers at: 'WWW-Authenticate').
		self assert: (cred realm = 'TEST').
		client session addCredential: cred.
		response := client get: 'http://localhost:1701/echo/foo'.
		self assert: (response statusLine code = 200).
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnDispatcherDelegateTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnDispatcherDelegateTest methodsFor: 'testing' stamp: 'NickAger 5/9/2011 21:49'!
testDispatcherDelegate
	| server |
	server := (ZnServer on:  1701)
		delegate: (ZnDispatcherDelegate new 
			map: '/hello' to: [ :request :response | response entity: (ZnStringEntity html: '<h1>hello server</h1>') ];
			map: '/' to: [ :request :response | response entity: (ZnStringEntity html: '<h1>default</h1>') ]).
	[
		| client response |
		server start.

		client := ZnHttpClient new
			url: 'http://localhost:1701/missing'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 404).
		
		client := ZnHttpClient new
			url: 'http://localhost:1701/'.
		response := client get.
		self assert: (client contentType = ZnMimeType textHtml).
		self assert: (client status = 200).
		
		client := ZnHttpClient new
			url: 'http://localhost:1701/hello'.
		response := client get.
		self assert: (client contentType = ZnMimeType textHtml).
		self assert: (client status = 200)
	] ensure: [ server stop ]
! !

TestCase subclass: #ZnEntityReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 16:03'!
testChunked
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input asByteArray readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 16:04'!
testChunkedWithExtraHeaders
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, 
		'X-Foo:bar', String crlf, 
		String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input asByteArray readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'.
	self assert: (headers at: 'X-Foo') = 'bar'! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:08'!
testReadStreaming
	| data headers reader entity |
	data := ((1 to: 32) collect: [ :each | (0 to: 9) atRandom ]) asByteArray.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: ZnMimeType applicationOctetStream printString;
		at: 'Content-Length' put: data size printString.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: data readStream;
		streaming.
	entity := reader readEntity.
	self assert: entity contentType = ZnMimeType applicationOctetStream.
	self assert: entity contentLength = data size.
	self assert: entity contents = data! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:13'!
testReadStreamingWriting
	| data headers reader entity output |
	data := ((1 to: 32) collect: [ :each | (0 to: 9) atRandom ]) asByteArray.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: ZnMimeType applicationOctetStream printString;
		at: 'Content-Length' put: data size printString.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: data readStream;
		streaming.
	entity := reader readEntity.
	self assert: entity contentType = ZnMimeType applicationOctetStream.
	self assert: entity contentLength = data size.
	output := ByteArray streamContents: [ :stream | entity writeOn: stream ].
	self assert: output = data! !

TestCase subclass: #ZnEntityTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/27/2011 17:15'!
testMultiPartFormDataWriteRead
	| input output bytes |
	input := (ZnMultiPartFormDataEntity new)
		addPart: (ZnMimePart fieldName: 'extra' value: 'my-extra');
		addPart: (ZnMimePart fieldName: 'info' value: 'my-info');
		addPart: (ZnMimePart fieldName: 'file' fileName: 'foo.txt' entity: (ZnEntity text: 'Zinc HTTP Components'));
		yourself.
	self assert: input contentLength notNil.
	self assert: input contentLength > 0.
	self assert: input contentType = ZnMimeType multiPartFormData.
	bytes := ByteArray streamContents: [ :stream | input writeOn: stream ].
	output := (ZnMultiPartFormDataEntity type: input contentType) readFrom: bytes readStream.
	self assert: (output partNamed: 'extra') fieldValueString = 'my-extra'.
	self assert: (output partNamed: 'info') fieldValueString = 'my-info'.
	self assert: (output partNamed: 'file') contents = 'Zinc HTTP Components'.
	output := (ZnMultiPartFormDataEntity type: input contentType length: input contentLength) readFrom: bytes readStream.
	self assert: (output partNamed: 'extra') fieldValueString = 'my-extra'.
	self assert: (output partNamed: 'info') fieldValueString = 'my-info'.
	self assert: (output partNamed: 'file') contents = 'Zinc HTTP Components'.

	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 15:41'!
testReading
	| contents entity |
	contents := 'This is a test'.
	entity := ZnEntity 
				readFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size.
	self assert: entity contents isString.
	self assert: entity string = contents.
	self assert: entity contentLength = contents size.
	self assert: entity contentType = ZnMimeType textPlain ! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/14/2010 12:13'!
testStringEntityEncoderInitialization
	| entity response |
	entity := ZnEntity text: 'Regression test'.
	self assert: entity hasEncoder not.
	response := ZnResponse ok: entity.
	self assert: entity hasEncoder.
	ByteArray streamContents: [ :stream | response writeOn: stream ].
	self assert: entity hasEncoder
	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8ReadingDetermined
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity type: ZnMimeType textPlain length: 10.
	bytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	entity readFrom: bytes readStream.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	self assert: entity contents = string! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8ReadingUndetermined
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity type: ZnMimeType textPlain.
	bytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	entity readFrom: bytes readStream.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	self assert: entity contents = string! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8Writing
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity text: string.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	bytes := ByteArray streamContents: [ :stream | entity writeOn: stream ].
	self assert: bytes = #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 10:11'!
testWritingApplicationUrlEncoding
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity at: 'foo' put: 'bar'.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=bar'.
	self assert: entity contentLength = 7! !

TestCase subclass: #ZnFixedClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnFixedClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/28/2010 12:58'!
testGetSmallHTMLDocument
	| client response |
	client := ZnFixedClient host:	 'homepage.mac.com'.
	[
	response := client get: '/svc/Zinc-HTTP-Components/small.html'.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small') ] 
		ensure: [ client close ]! !

TestCase subclass: #ZnHTTPSocketFacadeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/30/2011 13:59'!
testExtendUrlWithArgs
	| url |
	url := ZnHTTPSocketFacade 
		extendUrl: 'http://www.foo.com/bar' 
		withArguments: (Dictionary new
			at: 'x' put: #('1');
			at: 'z' put: #('aaa' 'bbb');
			yourself).
	self assert: url host = 'www.foo.com'.
	self assert: url path = 'bar'.
	self assert: (url queryAt: 'x') = '1'.
	self assert: (url queryAt: 'z') = #('aaa' 'bbb')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:17'!
testGetSmallHTMLDocument
	| mimeDocument |
	mimeDocument := ZnHTTPSocketFacade httpGetDocument: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (mimeDocument contents includesSubString: 'small').
	self assert: (mimeDocument contentType includesSubString: 'text/html')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/14/2010 13:18'!
testGetSmallHTMLStream
	| stream |
	stream := ZnHTTPSocketFacade httpGet: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	self assert: (stream contents includesSubString: 'small')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/4/2010 12:47'!
testPut
	| server result dataString |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'user' password: 'secret').
	dataString := String streamContents: [ :stream | 
		1 to: 67 do: [ :each | stream nextPut: (Character digitValue: each \\ 9) ] ].
	[ 
		server start.
		result := ZnHTTPSocketFacade httpPut: dataString to: 'http://localhost:1701/echo/foo' user: 'user' passwd: 'secret'.
		self assert: (result beginsWith: 'HTTP/1.1 200 OK').
		self assert: (result includesSubString: '67B')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnHeadersTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:59'!
testMergeValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' put: 'bar=1' ifPresentMerge: [ :old :new | old, ';', new ].
	self assert: (headers at: 'Set-Cookie') = 'foo=1;bar=1'
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:57'!
testMultiValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	self assert: (headers at: 'Set-Cookie') = #('foo=1' 'bar=1')
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 21:03'!
testMultiValuedStreaming
	| headers keysAndValues |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	keysAndValues := OrderedCollection streamContents: [ : stream |
		headers headersDo: [ :key :value |
			stream nextPut: key; nextPut: value ] ].
	self assert: keysAndValues  = #('Set-Cookie' 'foo=1' 'Set-Cookie' 'bar=1') asOrderedCollection 
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:55'!
testNormalization
	| headers |
	headers := ZnHeaders new.
	headers at: 'content-TYPE' put: 'text/plain'.
	self assert: (headers includesKey: 'content-type').
	self assert: (headers includesKey: 'content-TYPE').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	headers at: 'CONTENT-type' put: 'text/html'.
	self assert: (headers at: 'Content-Type') = 'text/html'.

	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:16'!
testReading
	| string headers |
	string := 'Content-Type: text/plain', String crlf, 'Content-Length: 128', String crlf.
	headers := ZnHeaders readFrom: string readStream.
	self assert: (headers includesKey: 'Content-Type').
	self assert: (headers includesKey: 'Content-Length').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	self assert: (headers at: 'Content-Length') = '128'.! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:20'!
testWriting
	| headers string |
	headers := ZnHeaders new 
		at: 'Content-Type' put: 'text/plain'; 
		at: 'Content-Length' put: '128';
		yourself.
	string := String streamContents: [ :stream | headers writeOn: stream ].
	self assert: (string includesSubString: 'Content-Type: text/plain', String crlf).
	self assert: (string includesSubString: 'Content-Length: 128', String crlf).
	self assert: (string occurrencesOf: Character cr) = 2.
	self assert: (string occurrencesOf: Character lf) = 2! !

TestCase subclass: #ZnHttpClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:28'!
testBasicAuthorization
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			auth: 'foo' password: 'secret'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/12/2011 10:08'!
testBasicAuthorizationFailure
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			auth: 'foo' password: 'wrong'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client isAuthenticationRequired).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2011 12:51'!
testCookieAt
	| client response |
	client := ZnHttpClient new url: 'http://www.pharo-project.org'.
	response := client get.
	self assert: ((client cookieAt: 'cmsbox') notNil)! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:28'!
testDelete
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnHttpClient new
					url: 'http://localhost:1701/echo/foo'.
		response := client delete.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
		self assert: (response  includesSubString: 'DELETE').
		self assert: (response  includesSubString: 'DELETE')
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:28'!
testDigestAuthorization
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			digestAuth: 'foo' password: 'secret'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/12/2011 10:08'!
testDigestAuthorizationFailure
	| server response client |
	server := ZnServer on: 1701.
	server authenticator: (ZnDigestAuthenticator username: 'foo' password: 'secret' realm: 'TEST').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnHttpClient new
			url: 'http://localhost:1701/echo/foo';
			digestAuth: 'foo' password: 'wrong'.
		response := client get.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client isAuthenticationRequired).
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/1/2010 20:59'!
testGet
	| client response |
	client := ZnHttpClient new.
	response := client 
		url: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html';
		get.
	self assert: response notNil.
	self assert: (client status = 200)! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'MattKennedy 10/4/2010 10:37'!
testGetMultParam
	| client response |
	client := ZnHttpClient new 
		url: 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html';
		parameterAt: 'test' add: 'value1';
		parameterAt: 'test' add: 'value2'.
	self assert: (client params at: 'test') isArray.
	response := client get.
	self assert: response notNil.
	self assert: (client status = 200)! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:28'!
testPost
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnHttpClient new
					url: 'http://localhost:1701/echo/foo';
					parameterAt: 'foo' put: 'bar';
					parameterAt: 'baz' put: 'bang'. 
		response := client post.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
		self assert: (response  includesSubString: 'POST').
		self assert: (response  includesSubString: 'bar')
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testPut
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnHttpClient new
					url: 'http://localhost:1701/echo/foo';
					parameterAt: 'foo' put: 'bar';
					parameterAt: 'baz' put: 'bang'. 
		response := client put.
		self assert: (client contentType = ZnMimeType textPlain).
		self assert: (client status = 200).
		self assert: (response  includesSubString: 'PUT')
	]
		ensure: [ server stop ]! !

!ZnHttpClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/14/2011 22:00'!
testRelativeRedirect
	| server response client |
	(server := ZnServer on: 1701) delegate: (ZnValueDelegate with: [ :request | 
		request uri firstPathSegment = 'one'
			ifTrue: [ ZnResponse redirect: 'two' ]
			ifFalse: [
				request uri firstPathSegment = 'two'
					ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
		 			ifFalse: [ ZnResponse notFound: request uri ] ] ] ).
	[ 
		server start.
		self assert: server isRunning & server isListening.
		(client := ZnHttpClient new) url: 'http://localhost:1701/one'.
		response := client post.
		self assert: response = 'OK!!'
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnLimitedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:47'!
testBinary
	| data limitedReadStream |
	data := #(0 1 2 3 4 5 6 7 8 9) asByteArray.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: limitedReadStream upToEnd = #(0 1 2 3 4) asByteArray! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:47'!
testBinaryAll
	| data limitedReadStream |
	data := #(0 1 2 3 4 5 6 7 8 9) asByteArray.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: data size.
	self assert: limitedReadStream upToEnd = data! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:24'!
testNextCount
	| data stream |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 8.
	self assert: (stream next: 4) = '0123'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:26'!
testNextCountInto
	| data stream buffer |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 8.
	buffer := String new: 4.
	self assert: (stream next: 4 into: buffer) = '0123'.
	self assert: buffer = '0123'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:28'!
testNextCountIntoShort
	| data stream buffer |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 5.
	buffer := String new: 6.
	self assert: (stream next: 6 into: buffer) = '01234'.
	self assert: buffer = (String new: 6)
	! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:24'!
testNextCountShort
	| data stream |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: (stream next: 6) = '01234'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:21'!
testNextN! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 13:04'!
testSimple
	| data limitedReadStream |
	data := '0123456789'.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: limitedReadStream upToEnd = '01234'! !

TestCase subclass: #ZnLineReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:22'!
testBinary
	| input reader |
	input := ('Foo', String crlf, 'Bar', String crlf) asByteArray.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:21'!
testLineTooLong
	| input reader |
	input := (String new: 128) atAllPut: $X.
	reader := (ZnLineReader on: input readStream) limit: 64.
	self should: [ reader nextLine ] raise: ZnLineTooLong  ! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:02'!
testSimple
	| input reader |
	input := 'Foo', String crlf, 'Bar', String crlf.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

TestCase subclass: #ZnLogSupportTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/29/2011 14:59'!
testFilter
	| logSupport memoryLogger |
	logSupport := ZnLogSupport newEnabled.
	memoryLogger := ZnMemoryLogger new.
	memoryLogger filter: #info.
	logSupport addListener: memoryLogger.
	logSupport info: 'Testing'.
	self assert: memoryLogger logEvents first message = 'Testing'.
	logSupport debug: 'Void'.
	self assert: memoryLogger logEvents size = 1     
	! !

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/13/2011 00:23'!
testLogEvent
	| logEvent now |
	now := TimeStamp now.
	logEvent := ZnLogEvent info: 'Testing'.
	self assert: logEvent timeStamp >= now.
	self assert: logEvent processId isInteger.
	self assert: logEvent category = #info.
	self assert: logEvent message = 'Testing'  ! !

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/29/2011 11:42'!
testSimple 
	| logSupport memoryLogger |
	logSupport := ZnLogSupport newEnabled.
	memoryLogger := ZnMemoryLogger new.
	logSupport addListener: memoryLogger.
	logSupport info: 'Testing'.
	self assert: memoryLogger logEvents first message = 'Testing'.
	logSupport removeListener: memoryLogger.
	logSupport info: 'Void'.
	self assert: memoryLogger logEvents size = 1     
	! !

TestCase subclass: #ZnMagicCookieJarTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:25'!
cookieString
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.google.com'! !

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:31'!
cookieStringAlt
	^'PREFS=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.pharo-project.org'! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:19'!
testAdd
	| jar count |
	jar := ZnCookieJar new.
	count := jar cookies size.
	jar add: (ZnCookie fromString: self cookieString for: 'www.google.com' asZnUrl).
	self assert: ((jar cookies size) = (count + 1))! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:03'!
testCookieAtForUrl
	| jar c1 c2 |
	jar := ZnCookieJar new.
	c1 := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	c2 := ZnCookie fromString: self cookieStringAlt for: 'http://www.pharo-project.org' asZnUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookieAt: 'PREF' forUrl: 'http://www.google.com' asZnUrl) notNil).
	self assert: ((jar cookieAt: 'foobar' forUrl: 'http://www.google.com' asZnUrl) isNil)! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:02'!
testCookiesForUrl
	| jar c1 c2 |
	jar := ZnCookieJar new.
	c1 := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	c2 := ZnCookie fromString: self cookieStringAlt for: 'http://www.pharo-project.org' asZnUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookiesForUrl: 'http://www.google.com' asZnUrl) size = 1)! !

TestCase subclass: #ZnMagicCookieTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMagicCookieTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 15:16'!
cookieString
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/; domain=.google.com'! !

!ZnMagicCookieTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 16:11'!
cookieStringSubpath
	^'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires=Thu, 27-Sep-2012 17:49:00 GMT; path=/test/; domain=.google.com'! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testFromString
	| cookie |
	cookie := ZnCookie fromString: self cookieString for: 'www.google.com' asZnUrl.
	self assert: (cookie name = 'PREF').
	self assert: (cookie path notNil).
	self assert: (cookie domain = '.google.com').
	self assert: (cookie isExpired not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:01'!
testInDomain
	| cookie |
	cookie := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	self assert: (cookie isInDomain: 'http://www.google.com' asZnUrl).
	self assert: (cookie isInDomain: 'http://google.com' asZnUrl).
	self assert: ((cookie isInDomain: 'http://pharo-project.org' asZnUrl) not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testInPath
	| cookie |
	cookie := ZnCookie fromString: self cookieStringSubpath for: 'www.google.com' asZnUrl.
	self assert: (cookie isInPath: 'www.google.com/test/' asZnUrl).
	self assert: ((cookie isInPath: 'www.google.com' asZnUrl) not)
	! !

TestCase subclass: #ZnMimeTypeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 19:59'!
testAsMimeType
	self assert: 'text/plain' asZnMimeType = ZnMimeType textPlain.
	self assert: ZnMimeType applicationOctetStream asZnMimeType = ZnMimeType applicationOctetStream! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:45'!
testDefault
	self assert: ZnMimeType default = ZnMimeType applicationOctetStream.
	self assert: ZnMimeType default == ZnMimeType applicationOctetStream! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:44'!
testIdentity
	self assert: ZnMimeType textPlain = ZnMimeType textPlain.
	self assert: ZnMimeType textPlain == ZnMimeType textPlain! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/2/2010 11:29'!
testReading
	| mimeType |
	mimeType := ZnMimeType fromString: 'text/plain; charset=utf-8'.
	self assert: (mimeType main = 'text').
	self assert: (mimeType sub = 'plain').
	self assert: (mimeType charSet = 'utf-8').
	self assert: mimeType isCharSetUTF8.
	self assert: mimeType isBinary not! !

!ZnMimeTypeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/2/2010 11:29'!
testWriting
	| mimeType |
	(mimeType := ZnMimeType main: 'text' sub: 'plain')
		charSet: 'utf-8'.
	self assert: mimeType printString = 'text/plain;charset=utf-8'.
	self assert: mimeType isCharSetUTF8.
	self assert: mimeType isBinary not! !

TestCase subclass: #ZnMultiValueDictionaryTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMultiValueDictionaryTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:48'!
testMultiValues
	| dictionary values keys |
	dictionary := ZnMultiValueDictionary new.
	dictionary at: 'foo' add: 1; at: 'foo' add: 2.
	self assert: (dictionary at: 'foo') = #(1 2).
	self assert: dictionary keys asArray = #('foo').
	values := OrderedCollection new.
	keys := OrderedCollection new.
	dictionary keysAndValuesDo: [ :key :value | keys add: key. values add: value ].
	self assert: values = (OrderedCollection with: 1 with: 2).
	self assert: keys = (OrderedCollection with: 'foo' with: 'foo')
	! !

TestCase subclass: #ZnRequestLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:08'!
testReading
	| requestLine string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.1', String crlf.
	requestLine := ZnRequestLine readFrom: string readStream.
	self assert: requestLine method = #GET.
	self assert: requestLine uriPathQueryFragment = '/foo/bar/xyz.txt'.
	self assert: requestLine version = ZnConstants defaultHTTPVersion ! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:46'!
testReadingWrongMethod
	| string |
	string := 'GETT /foo/bar/xyz.txt HTTP/1.1', String crlf.
	self should: [ ZnRequestLine readFrom: string readStream ] raise: ZnUnknowHttpMethod! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:47'!
testReadingWrongVersion
	| string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.5', String crlf.
	self should: [ ZnRequestLine readFrom: string readStream ] raise: ZnUnknowHttpVersion! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:11'!
testWriting
	| requestLine string |
	requestLine := ZnRequestLine method: 'GET' uri: '/foo/bar/xyz.txt'.
	string := String streamContents: [ :stream | requestLine writeOn: stream ].
	self assert: string = ('GET /foo/bar/xyz.txt HTTP/1.1', String crlf)! !

TestCase subclass: #ZnRequestTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 20:25'!
testBasicAuthenticate
	| request |
	request := ZnRequest new.
	request setBasicAuthenticationUsername: 'user' password: 'secret'.
	self assert: (request headers at: 'Authorization') = 'Basic dXNlcjpzZWNyZXQ='! !

!ZnRequestTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 11:23'!
testCookies
	| input request cookies testCookie1 testCookie2 |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Cookie: testCookie1=123; testCookie2=321', String crlf,
		'Host: foo.com', String crlf, 
		'Agent: SUnit', String crlf, 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	
	cookies := request headers cookies.
	testCookie1 := cookies at: 'testCookie1'.
	testCookie2 := cookies at: 'testCookie2'.
	
	self assert: testCookie1 notNil.
	self assert: testCookie1 value = '123'.	
	
	self assert: testCookie2 notNil.
	self assert: testCookie2 value = '321'.	

! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/4/2010 13:34'!
testReading
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Agent: SUnit', String crlf, 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	self assert: request method = #GET.
	self assert: request hasHeaders.
	self assert: (request headers at: 'Host') = 'foo.com'.
	self assert: request hasEntity not
! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/4/2010 13:35'!
testReadingWithEntity
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Content-Length: 8', String crlf, 
		'Content-Type: text/plain', String crlf, 
		String crlf, 
		'12345678'.
	request := ZnRequest readFrom: input asByteArray readStream.
	self assert: request method = #GET.
	self assert: request hasHeaders.
	self assert: request contentType = ZnMimeType textPlain.
	self assert: request contentLength = 8.
	self assert: request hasHeaders.
	self assert: request entity contents = '12345678'
! !

TestCase subclass: #ZnResponseTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnResponseTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 11:30'!
testCookie
	| response cookie1  responseString |
	response := ZnResponse ok: (ZnStringEntity html: '<h1>hello world</h1>').
	cookie1 := ZnCookie new.
	cookie1 
		name: 'testCookie1';
		value: '123'.
		
	response addCookie: cookie1.
	
	responseString := String streamContents: [ :stream | response writeOn: stream ].
	
	self assert: (responseString includesSubString: 'Set-Cookie: testCookie1=123')	

	
		
		
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 11:30'!
testCookies
	| response cookie1 cookie2 responseString |
	response := ZnResponse ok: (ZnStringEntity html: '<h1>hello world</h1>').
	cookie1 := ZnCookie new.
	cookie1 
		name: 'testCookie1';
		value: '123'.
		
	cookie2 := ZnCookie new.
	cookie2 
		name: 'testCookie2';
		value: '321'.
		
	response addCookie: cookie1.
	response addCookie: cookie2.
	
	responseString := String streamContents: [ :stream | response writeOn: stream ].
	
	self assert: (responseString includesSubString: 'Set-Cookie: testCookie1=123').  
	self assert: (responseString includesSubString: 'Set-Cookie: testCookie2=321').  	

	
		
		
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testCreated
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse created: uri.
	self assert: response code = 201.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubString: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testNotFound
	| response |
	response := ZnResponse notFound: 'http:///secret.txt'.
	self assert: response code = 404.
	self assert: (response headers includesKey: 'Server').
	self assert: (response headers includesKey: 'Date').
	self assert: (response entity contents includesSubString: 'secret.txt')! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testRedirect
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse redirect: uri.
	self assert: response code = 302.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubString: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/7/2011 19:50'!
testSlashdotGzipChunked
	| request stream response gzip |
	(request := ZnRequest get: 'http://slashdot.org')
		setConnectionClose;
		setAcceptEncodingGzip.
	stream := ZnNetworkingUtils socketStreamToUrl: request url.
	response := [ 
  		request writeOn: stream. 
  		stream flush. 
  		ZnResponse readFrom: stream ] ensure: [ stream close ].
	self assert: response code = 200.
	self assert: ((response headers at: 'Content-Type') beginsWith: 'text/html').
	self assert: (response headers at: 'Content-Encoding' ifAbsent: [ 'gzip' ]) = 'gzip'.
	self assert: (response headers at: 'Transfer-Encoding' ifAbsent: [ 'chunked' ]) = 'chunked'.
	self assert: (response entity contents includesSubString: 'Slashdot')
! !

!ZnResponseTests methodsFor: 'as yet unclassified' stamp: 'SvenVanCaekenberghe 12/3/2010 21:29'!
testWritingBinary
	| response bytes string |
	response := ZnResponse ok: (ZnEntity text: 'Okay').
	bytes := ByteArray streamContents: [ :stream | response writeOn: stream ].
	string := bytes asString.
	self assert: (string includesSubString: '200 OK').
	self assert: (string includesSubString: 'Okay')! !

!ZnResponseTests methodsFor: 'as yet unclassified' stamp: 'SvenVanCaekenberghe 12/3/2010 21:30'!
testWritingCharacter
	| response string |
	response := ZnResponse ok: (ZnEntity text: 'Okay').
	string := String streamContents: [ :stream | response writeOn: stream ].
	self assert: (string includesSubString: '200 OK').
	self assert: (string includesSubString: 'Okay')! !

TestCase subclass: #ZnServerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testAuthorizationFailed
	| server response |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient get: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Basic').
		self assert: ((response headers at: 'WWW-Authenticate') includesSubString: 'Zinc')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testAuthorizationSuccessful
	| server response |
	server := ZnServer on: 1701.
	server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient get: 'http://localhost:1701/echo/foo' username: 'foo' password: 'secret'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'Zinc').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testEcho
	| server response |
	server := ZnServer on: 1701.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient get: 'http://localhost:1701/echo/foo'.
		self assert: (response contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity contents includesSubString: 'Zinc').
		self assert: (response entity contents includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testGetUnicodeUtf8
	| server response html |
	server := ZnServer on: 1701.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnClient get: 'http://localhost:1701/unicode'.
		self assert: (response contentType = ZnMimeType textHtml).
		self assert: (response statusLine code = 200).
		self assert: response contentType isCharSetUTF8.
		html := response entity contents.
		self assert: (html includesSubString: 'Unicode').
		0 to: 16r024F do: [ :each | self assert: (html includes: each asCharacter) ]
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnStatusLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:09'!
testReading
	| statusLine string |
	string := 'HTTP/1.1 200 OK', String crlf.
	statusLine := ZnStatusLine readFrom: string readStream.
	self assert: statusLine code = 200.
	self assert: statusLine reason = 'OK'.
	self assert: statusLine version = ZnConstants defaultHTTPVersion ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:44'!
testReadingWrongCode
	| string |
	string := 'HTTP/1.0 1000 OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknowHttpStatusCode ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:43'!
testReadingWrongVersion
	| string |
	string := 'HTTP/0.9 200 OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknowHttpVersion! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:48'!
testReadingWrongVersion2
	| string |
	string := 'HTTP/0.9 Foo OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknowHttpVersion! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 09:03'!
testWriting
	| statusLine string |
	statusLine := ZnStatusLine ok.
	string := String streamContents: [ :stream | statusLine writeOn: stream ].
	self assert: string = ('HTTP/1.1 200 OK', String crlf)! !

TestCase subclass: #ZnUrlTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:40'!
testAsZnUrl
	| url1 url2 url3 |
	url1 := 'http://www.example.com:8080/foo/bar/doc.txt?x=1&y=2#mark'.
	self assert: url1 asZnUrl = url1 asUrl asZnUrl.
	url2 := 'http://www.google.com'.
	self assert: url2 asZnUrl = url2 asUrl asZnUrl.
	url3 := 'http://www.google.com?q=Pharo'.
	self assert: url3 asZnUrl = url3 asUrl asZnUrl.
	"self assert: '' asZnUrl = '' asUrl asZnUrl."
	"self assert: '/' asZnUrl = '/' asUrl asZnUrl."

! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:05'!
testAuthority
	self assert: 'http://localhost:8080/foo/bar/doc.txt' asZnUrl authority = 'localhost:8080'.
	self assert: 'http://www.google.com?q=Smalltalk' asZnUrl authority = 'www.google.com'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/17/2011 10:29'!
testEncodedSlash
	self assert: 'http://example.com/foo//' asZnUrl pathPrintString = '/foo/'.
	self assert: 'http://example.com/foo//bar/' asZnUrl pathPrintString = '/foo/bar/'.
	self assert: 'http://example.com/foo//bar/file.txt' asZnUrl pathPrintString = '/foo/bar/file.txt'.

	self assert: 'http://example.com/foo/%2F' asZnUrl pathPrintString = '/foo/%2F'.
	self assert: 'http://example.com/foo/%2Fbar/' asZnUrl pathPrintString = '/foo/%2Fbar/'.
	self assert: 'http://example.com/foo/%2F/bar/' asZnUrl pathPrintString = '/foo/%2F/bar/'.
	self assert: 'http://example.com/foo/%2Ffoo.txt' asZnUrl pathPrintString = '/foo/%2Ffoo.txt'.

! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:42'!
testIsSlash
	self assert: '' asZnUrl isSlash.
	self assert: '/' asZnUrl isSlash.
	self assert: '/foo' asZnUrl isSlash not.
	self assert: 'http://host/foo' asZnUrl isSlash not.! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/13/2011 10:44'!
testLocalHost
	self assert: 'http://localhost:8080/foo' asZnUrl isLocalHost.
	self assert: 'http://127.0.0.1:8080/foo' asZnUrl isLocalHost.
	self assert: 'http://LOCALHOST:8080/foo' asZnUrl isLocalHost.
	self deny: 'http://zn.stx.eu' asZnUrl isLocalHost.
	self deny: '' asZnUrl isLocalHost.! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 12:17'!
testParsingEmpty
	| url |
	url := ZnUrl fromString: ''.
	self assert: url isEmpty.
	url := ZnUrl fromString: '/'.
	self assert: url isEmpty.
	url := ZnUrl fromString: '//./foo/../'.
	self assert: url isEmpty! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:36'!
testParsingEscape
	| url |
	url := ZnUrl fromString: 'http://localhost/foo%62%61%72'.
	self assert: url firstPathSegment = 'foobar'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/3/2011 16:41'!
testParsingSimple
	| url |
	url := ZnUrl fromString: 'http://www.example.com:8080/foo/bar/baz.txt?x=1&y=2#m1'.
	self assert: url scheme = #http.
	self assert: url host = 'www.example.com'.
	self assert: url port = 8080.
	self assert: url hasPath.
	self assert: url isFile.
	self assert: url hasQuery.
	self assert: url hasFragment.
	self assert: url fragment = 'm1'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:50'!
testParsingWrongEscape
	self should: [ ZnUrl fromString: 'http://foo:8080/foo%%bar' ] raise: ZnPercentEncodingWrong ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:55'!
testParsingWrongEscapeQuery
	self should: [ ZnUrl fromString: 'http://foo:8080/foo?%%bar=1' ] raise: ZnPercentEncodingWrong ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 15:28'!
testParsingWrongPort
	self should: [ ZnUrl fromString: 'http://foo:bar' ] raise: ZnPortNotANumber   ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/18/2011 13:28'!
testParsingWrongScheme
	self should: [ ZnUrl fromString: 'htttp://foo:bar' ] raise: ZnUnknowScheme ! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 12:21'!
testPrintingSimple
	| url |
	(url := ZnUrl new)
		scheme: #http;
		host: 'www.seaside.st';
		port: 8080;
		addPathSegment: 'example';
		addPathSegment: 'foo.html';
		queryAt: 'q' put: '100';
		fragment: 'mark'.
	self assert: url authority = 'www.seaside.st:8080'.
	self assert: url isAbsolute.
	self assert: url isFile.
	self assert: url printString = 'http://www.seaside.st:8080/example/foo.html?q=100#mark'.
	self assert: url file = 'foo.html'.
	self assert: url directory = 'example'.
	self assert: url pathPrintString = '/example/foo.html'.
	self assert: url pathQueryFragmentPrintString = '/example/foo.html?q=100#mark'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:26'!
testQuery
	| url |
	url := 'http://foo.com/test?q' asZnUrl.
	self assert: url printString = 'http://foo.com/test?q'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:17'!
testRelative
	| url |
	url := 'http://api.foo.com:8080' asZnUrl.
	url parseFrom: '/user/1?format=full'.
	self assert: url printString = 'http://api.foo.com:8080/user/1?format=full'! !

!ZnUrlTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 13:57'!
testWriteUrlPathQueryFragmentOfOn
	| string |
	string := String streamContents: [ :stream |
		'http://host:7777/foo/bar/doc.txt?x=1#mark' asZnUrl printPathQueryFragmentOn:  stream ].
	self assert: string = '/foo/bar/doc.txt?x=1#mark'! !

TestCase subclass: #ZnUserAgentSessionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUserAgentSessionTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 15:11'!
dummyCredential
	^ZnBasicCredential new 
		username: 'test'; 
		password: 'foobar';
		realm: 'dummy';
		domain: 'test.com';
		yourself! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/7/2010 00:00'!
testAccessors
	| session |
	session := ZnUserAgentSession new.
	self assert: (session cookiejar isKindOf: ZnCookieJar).
	self assert: (session credentials notNil)! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:14'!
testAddCredential
	| session count |
	session := ZnUserAgentSession new.
	count := session credentials size.
	session addCredential: self dummyCredential.
	self assert: ((session credentials size) = (count + 1))! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/7/2010 00:00'!
testWithCookieJar
	self assert: ((ZnUserAgentSession withCookieJar: ZnCookieJar new) notNil)! !

TestCase subclass: #ZnUserAgentSettingsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 14:58'!
testAccessors
	| settings |
	settings := ZnUserAgentSettings defaultSettingsClass new.
	self assert: (settings agent notNil).
	self assert: (settings followRedirect isKindOf: Boolean).
	self assert: (settings redirectLimit notNil).
	self assert: (settings timeout notNil)! !

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/7/2010 00:00'!
testClassDefaults
	self assert: (ZnUserAgentSettings defaultCookieJar new isKindOf: ZnCookieJar).
	self assert: (ZnUserAgentSettings defaultSessionClass new isKindOf: ZnUserAgentSession).
	self assert: (ZnUserAgentSettings defaultSettingsClass new isKindOf: ZnUserAgentSettings)! !

!ZnUserAgentSettingsTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 14:59'!
testLoadSession
	| settings |
	settings := ZnUserAgentSettings defaultSettingsClass new.
	self assert: (settings loadSession isKindOf: ZnUserAgentSession)! !

TestCase subclass: #ZnUserAgentTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:21'!
testCookieAt
	| url client response |
	url := 'http://www.google.com/' asZnUrl.
	client := ZnUserAgent new.
	response := client get: url.
	self assert: ((client cookieAt: 'PREF') notNil)! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testDelete
	| server response client |
	server := ZnServer on: 1701.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		response := client delete: 'http://localhost:1701/echo/foo'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'DELETE').
		self assert: (response entity string includesSubString: 'foo')
	]
		ensure: [ server stop ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/14/2010 12:18'!
testErrorHandler
	| client flag |
	flag := false.
	client := ZnUserAgent new 
				"logProgressToTranscript;"
				errorHandler: [:error | flag := true ].
	client get: ''.
	self assert: flag! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2011 12:49'!
testFollowRedirect
	| url client response |
	url := 'http://www.pharo-project.org/' asZnUrl.
	client := ZnUserAgent new.
	client settings followRedirect: false.
	response := client get: url.
	self assert: (response isRedirect).
	client settings followRedirect: true.
	response := client get: url.
	self assert: response isSuccess! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:21'!
testGetSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	response := ZnUserAgent new get: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubString: 'small')! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:22'!
testHeadSmallHTMLDocument
	| url response |
	url := 'http://homepage.mac.com/svc/Zinc-HTTP-Components/small.html'.
	response := ZnUserAgent new head: url.
	self assert: response headers contentType = ZnMimeType textHtml.
	self assert: response statusLine code = 200! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testPost
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		response := client post: 'http://localhost:1701/echo/foo' data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'POST').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/15/2010 21:29'!
testPut
	| server response data client |
	server := ZnServer on: 1701.
	data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		response := client put: 'http://localhost:1701/echo/foo' data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubString: 'PUT').
		self assert: (response entity string includesSubString: data)
	]
		ensure: [ server stop ]! !

!ZnUserAgentTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/14/2011 21:54'!
testRelativeRedirect
	| server response client |
	(server := ZnServer on: 1701) delegate: (ZnValueDelegate with: [ :request | 
		request uri firstPathSegment = 'one'
			ifTrue: [ ZnResponse redirect: 'two' ]
			ifFalse: [
				request uri firstPathSegment = 'two'
					ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
		 			ifFalse: [ ZnResponse notFound: request uri ] ] ] ).
	[ 
		server start.
		self assert: server isRunning & server isListening.
		client := ZnUserAgent new.
		response := client post: 'http://localhost:1701/one' data: (ZnEntity text: 'data').
		self assert: response isSuccess.
		self assert: response contents = 'OK!!'
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnUtilsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/21/2011 20:25'!
testBase64
	| short long encoded legalCharactes |
	legalCharactes := (String withAll: ($A to: $Z), ($a to: $z), ($0 to: $9)), '='.
	short := String withAll: ((1 to: 16) collect: [ :each | 'abc' atRandom ]).
	encoded := ZnUtils encodeBase64: short.
	self assert: (ZnUtils decodeBase64: encoded) = short.
	self assert: (encoded allSatisfy: [ :each | legalCharactes includes: each ]).
	"We don't want line breaks!!"
	long := String withAll: ((1 to: 64) collect: [ :each | 'abc' atRandom ]).
	encoded := ZnUtils encodeBase64: long.
	self assert: (ZnUtils decodeBase64: encoded) = long.
	self assert: (encoded allSatisfy: [ :each | legalCharactes includes: each ])
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:09'!
testCapitalizeString
	self assert: (ZnUtils capitalizeString: 'content-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'CONTENT-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'content-TYPE') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'WWW-Authenticate') = 'Www-Authenticate'.
	self assert: (ZnUtils capitalizeString: 'Content-MD5') = 'Content-Md5'.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:48'!
testHttpDate
	| timestamp string |
	timestamp := (DateAndTime year: 2010 month: 9 day: 1 hour: 10 minute: 10 second: 10 offset: 0 seconds).
	string := ZnUtils httpDate: timestamp.
	self assert: (string = 'Wed, 01 Sep 2010 10:10:10 GMT')
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:10'!
testIsCapitalizedString
	self assert: (ZnUtils isCapitalizedString: 'Content-Type').
	self assert: (ZnUtils isCapitalizedString: 'CONTENT-type') not.
	self assert: (ZnUtils isCapitalizedString: 'content-TYPE') not.
	self assert: (ZnUtils isCapitalizedString: 'WWW-Authenticate') not.
	self assert: (ZnUtils isCapitalizedString: 'Connection')! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/11/2010 21:36'!
testQueryParsing
	| string fields |
	string := 'foo=100&x=', ('/a b' encodeForHTTP).
	fields := ZnUtils parseQueryFrom: string readStream.
	self assert: (fields at: 'foo') = '100'.
	self assert: (fields at: 'x') = '/a b'.
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 14:55'!
testQueryWriting
	| fields string |
	(fields := Dictionary new)
		at: 'foo' put: '100';
		at: 'bar' put: 'a b'.
	string := String streamContents: [ :stream | ZnUtils writeQueryFields: fields on: stream ].
	self assert: (string includesSubString: 'foo=1').
	self assert: (string includesSubString: 'bar=a%20b').! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 16:14'!
testStreamingBinary
	| data in out |
	data := ByteArray streamContents: [ :stream | 1 to: 10000 do: [ :each | stream nextPut: #(1 2 3) atRandom ] ].
	in := data readStream.
	out := WriteStream on: (ByteArray new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/17/2010 16:14'!
testStreamingNonBinary
	| data in out |
	data := String streamContents: [ :stream | 1 to: 10000 do: [ :each | stream nextPut: 'abc' atRandom ] ].
	in := data readStream.
	out := WriteStream on: (String new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !
